==> react-router-1.2.0.tgz: package/lib/internal/ReactUtils.js <==
import React from 'react';
import IndexRoute from '../IndexRoute';
import Redirect from '../Redirect';
/**
 * Transform from React Elements tree to a plain json
 * @param {import('react').ComponentType} root
 * @param {Object} parent
 * @param {Number} level
 */

export var fromReactTreeToJSON = function fromReactTreeToJSON(root, parent, level) {
  if (parent === void 0) {
    parent = {};
  }

  if (level === void 0) {
    level = 1;
  }

  // Ignore non-elements. This allows people to more
  // easily inline conditionals in their route config.
  if (! /*#__PURE__*/React.isValidElement(root)) return;
  var props = root.props,
      type = root.type;
  var component = props.component,
      path = props.path,
      children = props.children,
      getComponent = props.getComponent,
      id = props.id,
      from = props.from,
      to = props.to;
  var displayName = type.displayName;
  var node = Object.create(null);

  if (displayName === Redirect.displayName) {
    node.redirect = true;
    node.from = from;
    node.path = from;
    node.to = to;
  }

  if (displayName === IndexRoute.displayName) {
    node.index = true;
    parent.fromIndex = true;
    parent.indexNode = node;
  }

  if (level) node.level = level;
  if (id) node.id = id;
  if (component) node.component = component;
  if (getComponent) node.getComponent = getComponent;
  if (path) node.path = path;
  if (children) node.children = React.Children.toArray(children).map(function (child) {
    return fromReactTreeToJSON(child, node, level + 1);
  });
  return node;
};

==> react-router-1.9.0.tgz: package/lib/internal/ReactUtils.js <==
import { Children as ReactChildren, isValidElement } from 'react';
import IndexRoute from '../IndexRoute';
import Redirect from '../Redirect';
/**
 * Transform from React Elements tree to a plain json
 * @param {import('react').ComponentType} root
 * @param {Object} parent
 * @param {Number} level
 */

export var fromReactTreeToJSON = function fromReactTreeToJSON(root, parent, level) {
  if (parent === void 0) {
    parent = {};
  }

  if (level === void 0) {
    level = 1;
  }

  // Ignore non-elements. This allows people to more
  // easily inline conditionals in their route config.
  if (! /*#__PURE__*/isValidElement(root)) return;
  var props = root.props,
      type = root.type;
  var component = props.component,
      path = props.path,
      children = props.children,
      getComponent = props.getComponent,
      id = props.id,
      from = props.from,
      to = props.to,
      regexp = props.regexp;
  var displayName = type.displayName;
  var node = Object.create(null); // Path over Regexp

  if (!path && regexp) {
    node.regexp = regexp;
  }

  if (displayName === Redirect.displayName) {
    node.redirect = true;
    node.from = from;
    node.path = from;
    node.to = to;
  }

  if (displayName === IndexRoute.displayName) {
    node.index = true;
    parent.fromIndex = true;
    parent.indexNode = node;
  }

  if (level) node.level = level;
  if (id) node.id = id;
  if (component) node.component = component;
  if (getComponent) node.getComponent = getComponent;
  if (path) node.path = path;
  if (children) node.children = ReactChildren.toArray(children).map(function (child) {
    return fromReactTreeToJSON(child, node, level + 1);
  });
  return node;
};
